/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

 /*global
    getSelectMemoCount, getSelectMemoContent, getSelectBook, refreshGalleries, newBookBtnHandler, newBookCheckHandler,
    insertMemoTable, updateMemoTable, insertBookTable, getSelectIdMemo: false,
 */

var current_page,
    before_page,
    DEFAULT_SUBJECT = "note subject",
    DEFAULT_BODY = "What do you want to remember?",
    DEFAULT_BOOK = "Name",
    memo_id = null;

function subjectFocus() {
    var inputSubject = document.querySelector('#input_subject');

    if(inputSubject.value === DEFAULT_SUBJECT){
        inputSubject.value = '';
    }
    inputSubject.style.color = 'black';
}

function subjectBlur() {
    var inputSubject = document.querySelector('#input_subject');

    if(inputSubject.value === ''){
        inputSubject.value = DEFAULT_SUBJECT;
        inputSubject.style.color = '#9c979c';
    }
}

function bodyFocus() {
    var inputBody = document.querySelector('#input_body');

    if(inputBody.value === DEFAULT_BODY){
        inputBody.value = '';
    }
    inputBody.style.color = 'black';
    inputBody.style.verticalAlign="top";
}

function bodyBlur() {
    var inputBody = document.querySelector('#input_body');

    if(inputBody.value === ''){
        inputBody.value = DEFAULT_BODY;
        inputBody.style.color = '#9c979c';
    }
}

function bookFocus() {
    var inputBook = document.querySelector('#input_book');

    if(inputBook.value === DEFAULT_BOOK){
        inputBook.value = '';
    }
    inputBook.style.color = 'black';
    inputBook.style.verticalAlign="top";
}

function bookBlur() {
    var inputBook = document.querySelector('#input_book');

    if(inputBook.value === ''){
        inputBook.value = DEFAULT_BOOK;
        inputBook.style.color = '#9c979c';
    }
}

function pageHandler(page) {
    var galleryPage = document.querySelector('#page_gallery'),
        mainPage = document.querySelector('#page_main'),
        newNotePage = document.querySelector('#page_new_note'),
        newBookPage = document.querySelector('#page_new_book'),
        newPopup = document.querySelector('#pop_up_book'),
        pageMemo = document.querySelector('#page_memo');

    mainPage.style.display = "none";
    newBookPage.style.display = "none";
    newNotePage.style.display = "none";
    galleryPage.style.display = "none";
    newPopup.style.display = "none";
    pageMemo.style.display = "none";
    if(current_page !== "new_book" && current_page !== "book"){
        before_page = current_page;
    }


    if(page === "main"){
        mainPage.style.display = "block";
        current_page = "main";
        getSelectMemoCount();
        getSelectMemoContent();
    }
    else if(page === "note"){
        newNotePage.style.display = "block";
        current_page = "note";
    }
    else if(page === "book"){
        newBookPage.style.display = "block";
        getSelectBook();
        current_page = "book";
    }
    else if(page === "gallery"){
        galleryPage.style.display = "block";
        refreshGalleries();
        current_page = "gallery";
    }
    else if(page === "page_memo"){
        pageMemo.style.display = "block";
        current_page = "page_memo";
    }
}

function setGallery(array) {
    var main_gallery = document.querySelector('#main_gallery'),
        i;

    main_gallery.innerHTML = '';
    for(i=0; i<array.length; i++){
        main_gallery.innerHTML = main_gallery.innerHTML +
        "<input type='image' class='gallery_image'" +
        " src=" + array[i] +
        " onclick='clickGallery(this);'>";
    }
}

function clickGallery(e) {
    var note_picture = document.querySelector('#note_picture_area');

    note_picture.innerHTML = note_picture.innerHTML +
        "<img src=" + e.src + ">";
     pageHandler("note");
}

function checkHandler() {
    var inputSubject = document.querySelector('#input_subject'),
        inputBody = document.querySelector('#input_body'),
        inputBook = document.querySelector('#header_button'),
        noteBody = document.querySelector('#note_body'),
        input_body = document.querySelector('#input_body'),
        note_picture_area = document.querySelector('#note_picture_area'),
        book = inputBook.innerHTML,
        subject = inputSubject.value,
        body = inputBody.value,
        date = new Date(),
        insert_date,
        noteImg,
        image;

    noteImg = noteBody.querySelector('img');
    if(noteImg !== null){
        image = noteImg.src;
    }

    insert_date = date.getFullYear() + "/" + (date.getMonth()+1) + "/" + date.getDate();
    if(memo_id === null){
        insertMemoTable(subject, body, book, insert_date, image);
    }
    else {
        updateMemoTable(memo_id, subject, body, book, insert_date, image);
    }
    pageHandler("main");
    inputSubject.value = "note subject";
    inputBody.value = "What do you want to remember?";
    inputSubject.style.color = '#9c979c';
    inputBody.style.color = '#9c979c';
    note_picture_area.innerHTML = '';
    input_body.style.height = "50%";
}

function newBookBtnHandler() {
    var pop_up_book = document.querySelector('#pop_up_book');

    pop_up_book.style.display = 'block';
    current_page = "new_book";
}

function newBookCheckHandler() {
    var pop_up_book = document.querySelector('#pop_up_book'),
        inputBook = document.querySelector('#input_book');

    insertBookTable();
    pop_up_book.style.display = 'none';
    pageHandler("book");
    inputBook.value = DEFAULT_BOOK;
    inputBook.style.color = '#9c979c';
}

function clickBookHandler(book) {
    var header_button = document.querySelector('#header_button'),
        btntitleBook = document.querySelector('#note_title');

    header_button.innerHTML = book;
    btntitleBook.innerHTML = book;

    current_page = "new_book";
    if(before_page === "main") {
        pageHandler("main");
    }
    else if(before_page === "note") {
        pageHandler("note");
    }
}

function setMemoCount(count) {
    var memo_count = document.querySelector('#memo_count');

    memo_count.innerHTML = count;
}

function setMemoContent(id, subject, body, date, image) {
    var memo = document.querySelector('#main'),
        memo_string;

    memo_string = "<div class='memo' id=" + id + " onclick='clickMemo(this);'>" +
        "<div class='memo_subject'>" + subject + "</div>" +
        "<div class='memo_date'>" + date + "</div>" +
        "<div class='memo_body'>" + body + "</div>";

    if(image !== null){
        memo_string = memo_string +
            "<img src=" + image + " class='memo_image'>" +
            "</div>";
    }
    else {
        memo_string = memo_string +
            "</div>";
    }
    memo.innerHTML = memo.innerHTML + memo_string;
}

function clickMemo(e) {
    var page_memo = document.querySelector('#page_memo'),
        main_memo = document.querySelector('#main_memo'),
        img_src;

    memo_id = e.id;
    page_memo.getElementsByClassName('header_subject')[0].innerHTML =
        e.getElementsByClassName('memo_subject')[0].innerHTML;
    main_memo.innerHTML = e.getElementsByClassName('memo_body')[0].innerHTML;
    if( e.getElementsByTagName('img')[0] !== undefined){
        img_src = e.getElementsByTagName('img')[0].src;
        main_memo.innerHTML += "<img src=" + img_src + " class='page_memo_image'>";
    }
    pageHandler("page_memo");
}

function setBookContent(book) {
    var main_book = document.querySelector('#main_book');

    main_book.innerHTML = main_book.innerHTML + "<button type='button' class='btn_book_select' onclick='clickBookHandler(this.id)' id="+book+">"
        + book + "</button>";
}

function updateMemo() {
    getSelectIdMemo(memo_id);
}
function getUpdateMemo(subject, text, image) {
    var input_subject = document.querySelector("#input_subject"),
        input_body = document.querySelector("#input_body"),
        note_picture = document.querySelector('#note_picture_area');

    input_subject.value = subject;
    input_body.value = text;
    if(image !== null){
        note_picture.innerHTML = "<img src=" + image + ">";
    }
    pageHandler("note");
}


function initPage() {
    pageHandler("main");
}